Modules
Structs
- Compactor
Config - Configuration for compaction
- Compactor
Config Builder - Compaction configuration builder
- Filesystem
Entry - A filesystem entry in Minidex, containing information extracted from files, directories or symlinks by systems populating the index.
- Index
- A Minidex Index, managing both the in-memory and disk data. Insertions and deletions auto-commit to the Write-Ahead Log and may trigger compaction.
- Scoring
Config - Scoring configuration
- Scoring
Inputs - Scoring
Weights - Configurable weights for search result scoring.
- Search
Options - Search options, allowing filtering and custom scoring
- Search
Result - A Minidex search result, containing the found metadata for the given file
Enums
- Index
Error - Kind
- Volume
Type - Volume type, used to distinguish local volumes from remote and network volumes.
Functions
- tokenize
- A basic Unicode-aware tokenizer.