pub struct CompactorConfigBuilder { /* private fields */ }Expand description
Compaction configuration builder
Implementations
Sourceimpl CompactorConfigBuilder
impl CompactorConfigBuilder
pub fn new() -> Self
Sourcepub fn min_merge_count(self, min_merge_count: usize) -> Self
pub fn min_merge_count(self, min_merge_count: usize) -> Self
Set the minimum number of live segments required to trigger compaction
Sourcepub fn flush_threshold(self, flush_threshold: usize) -> Self
pub fn flush_threshold(self, flush_threshold: usize) -> Self
Set the minimum number of items in memory required to trigger flushing and compaction
Sourcepub fn tombstone_threshold(self, tombstone_threshold: usize) -> Self
pub fn tombstone_threshold(self, tombstone_threshold: usize) -> Self
Set the minimum number of prefix tombstones required to trigger compaction
pub fn build(self) -> CompactorConfig