Crate minidex

Crate minidex 

Modules

category

Structs

CompactorConfig
Configuration for compaction
CompactorConfigBuilder
Compaction configuration builder
FilesystemEntry
A filesystem entry in Minidex, containing information extracted from files, directories or symlinks by systems populating the index.
Index
A Minidex Index, managing both the in-memory and disk data. Insertions and deletions auto-commit to the Write-Ahead Log and may trigger compaction.
ScoringConfig
Scoring configuration
ScoringInputs
ScoringWeights
Configurable weights for search result scoring.
SearchOptions
Search options, allowing filtering and custom scoring
SearchResult
A Minidex search result, containing the found metadata for the given file

Enums

IndexError
Kind
VolumeType
Volume type, used to distinguish local volumes from remote and network volumes.

Functions

tokenize
A basic Unicode-aware tokenizer.

Type Aliases

Tombstone