Skip to main contentCrate minidex
Source - CompactorConfig
- Configuration for compaction
- CompactorConfigBuilder
- Compaction configuration builder
- FilesystemEntry
- A filesystem entry in Minidex, containing information extracted
from files, directories or symlinks by systems populating the index.
- Index
- A Minidex Index, managing both the in-memory and disk data.
Insertions and deletions auto-commit to the Write-Ahead Log
and may trigger compaction.
- ScoringConfig
- Configurable weights for search result scoring.
- SearchOptions
- Search options, allowing filtering and custom scoring
- SearchResult
- A Minidex search result, containing the found metadata for
the given file
- IndexError
- Kind